@@ -41,13 +41,14 @@ import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.Coprocessor;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.MiniHBaseCluster;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Get;
 import org.apache.hadoop.hbase.client.Put;
@@ -57,8 +58,10 @@ import org.apache.hadoop.hbase.client.RetriesExhaustedWithDetailsException;
 import org.apache.hadoop.hbase.client.Row;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
+import org.apache.hadoop.hbase.regionserver.HRegion;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.omid.HBaseShims;
 import org.apache.omid.TestUtils;
 import org.apache.omid.committable.CommitTable;
 import org.apache.omid.committable.hbase.HBaseCommitTableConfig;
@@ -154,15 +157,21 @@ public class TestCompaction {
     private void createTableIfNotExists(String tableName, byte[]... families) throws IOException {
         if (!admin.tableExists(TableName.valueOf(tableName))) {
             LOG.info("Creating {} table...", tableName);
-            HTableDescriptor desc = new HTableDescriptor(TableName.valueOf(tableName));
 
+            ArrayList<ColumnFamilyDescriptor> fams = new ArrayList<>();
             for (byte[] family : families) {
-                HColumnDescriptor datafam = new HColumnDescriptor(family);
-                datafam.setMaxVersions(MAX_VERSIONS);
-                desc.addFamily(datafam);
+                fams.add(ColumnFamilyDescriptorBuilder
+                    .newBuilder(family)
+                    .setMaxVersions(MAX_VERSIONS)
+                    .build());
             }
-
-            desc.addCoprocessor("org.apache.hadoop.hbase.coprocessor.AggregateImplementation",null,Coprocessor.PRIORITY_HIGHEST,null);
+            TableDescriptor desc = TableDescriptorBuilder
+                    .newBuilder(TableName.valueOf(tableName))
+                    .setColumnFamilies(fams)
+                    .setCoprocessor(CoprocessorDescriptorBuilder
+                            .newBuilder("org.apache.hadoop.hbase.coprocessor.AggregateImplementation")
+                            .setPriority(Coprocessor.PRIORITY_HIGHEST).build())
+                    .build();
             admin.createTable(desc);
             for (byte[] family : families) {
                 CompactorUtil.enableOmidCompaction(connection, TableName.valueOf(tableName), family);
@@ -521,7 +530,7 @@ public class TestCompaction {
 
         Transaction tx = tm.begin();
         Get get = new Get(Bytes.toBytes(rowId));
-        get.setMaxVersions(2 * MAX_VERSIONS);
+        get.readVersions(2 * MAX_VERSIONS);
         assertEquals(get.getMaxVersions(), (2 * MAX_VERSIONS), "Max versions should be set to " + (2 * MAX_VERSIONS));
         get.addColumn(fam, qual);
         Result result = txTable.get(tx, get);
@@ -542,7 +551,7 @@ public class TestCompaction {
 
         tx = tm.begin();
         get = new Get(Bytes.toBytes(rowId));
-        get.setMaxVersions(2 * MAX_VERSIONS);
+        get.readVersions(2 * MAX_VERSIONS);
         assertEquals(get.getMaxVersions(), (2 * MAX_VERSIONS), "Max versions should be set to " + (2 * MAX_VERSIONS));
         get.addColumn(fam, qual);
         result = txTable.get(tx, get);
@@ -558,8 +567,9 @@ public class TestCompaction {
     // directly after the flush, which we want to avoid.
     private void manualFlush(String tableName) throws Throwable {
         LOG.info("Manually flushing all regions and waiting 2 secs");
-        HBaseShims.flushAllOnlineRegions(hbaseTestUtil.getHBaseCluster().getRegionServer(0),
-                                         TableName.valueOf(tableName));
+        for (HRegion r : hbaseTestUtil.getHBaseCluster().getRegionServer(0).getRegions(TableName.valueOf(tableName))) {
+            r.flush(true);
+        }
         TimeUnit.SECONDS.sleep(2);
     }
 
@@ -785,9 +795,11 @@ public class TestCompaction {
         admin.disableTable(TableName.valueOf(TEST_TABLE));
         byte[] nonOmidCF = Bytes.toBytes("nonOmidCF");
         byte[] nonOmidQual = Bytes.toBytes("nonOmidCol");
-        HColumnDescriptor nonomidfam = new HColumnDescriptor(nonOmidCF);
-        nonomidfam.setMaxVersions(MAX_VERSIONS);
-        admin.addColumn(TableName.valueOf(TEST_TABLE), nonomidfam);
+        ColumnFamilyDescriptor nonomidfam = ColumnFamilyDescriptorBuilder
+                .newBuilder(nonOmidCF)
+                .setMaxVersions(MAX_VERSIONS)
+                .build();
+        admin.addColumnFamily(TableName.valueOf(TEST_TABLE), nonomidfam);
         admin.enableTable(TableName.valueOf(TEST_TABLE));
 
         byte[] rowId = Bytes.toBytes("testRow");
