@@ -17,7 +17,7 @@
  */
 package org.apache.omid.tso;
 
-import org.jboss.netty.channel.Channel;
+import io.netty.channel.Channel;
 
 import java.io.Closeable;
 import java.util.Collection;
